==> atmos-2.97.12.tar.gz: atmos-2.97.12/src/io.cpp <==
/*
    $Id$
    Copyright (C) 2009  Sternberg Astronomical Institute, MSU

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <iosfwd>
#include <iomanip>

#include <boost/io/ios_state.hpp>
#include <yalpa/io.h>

#include "io.h"

namespace std {

	static const int iword_index = std::ios_base::xalloc();

	std::ostream& indic( std::ostream& stm ){
		stm.iword(iword_index) = true;
		return stm;
	}
	std::ostream& operator<<( std::ostream& stm, const atmos::datum& m ){
		boost::io::ios_flags_saver fsaver( stm );
		if( std::ostream::sentry( stm ) ){
			int w = ( stm.flags() & std::ios::scientific )? 8 : 5;
			w = ( stm.iword(iword_index) )? w + 2 : w;
			int p = ( stm.iword(iword_index) ) ? 4 : std::max( 0, 4 - std::max( 1, (int)std::ceil(std::log10( m.mean ) ) ) );
			stm << std::setprecision(p) << std::setw(w) << m.mean << " "
				<< std::fixed << std::setprecision(3) << std::setw(7) << ( std::isfinite(m.errs) ? m.errs : 0 );
		}
		return stm;
	}
	std::ostream& operator<<( std::ostream& stm, const atmos::object& obj ){
		if( std::ostream::sentry( stm ) ){
			stm << obj.hd << stm.fill() << obj.name << stm.fill() << std::hours << std::sexagesimal << yalpa::make_angle( obj.coordinates.ra() ) << std::degrees << stm.fill() << yalpa::make_angle( obj.coordinates.dec() ) << stm.fill() << obj.vmag << stm.fill() << obj.bvind << stm.fill() << obj.sclass;
		}
		return stm;
	}
	std::istream& operator>>( std::istream& stm, atmos::object& obj ){
		if( std::istream::sentry( stm ) ){
			//O 2009-07-19 18:04:29 5191 Eta_UMa 13 47 32 +49 18 48  1.86 -0.19 B55
			double ra = 0,dec = 0;
			stm >> obj.hd >> obj.name >> std::sexagesimal >> std::hours >> yalpa::make_angle(ra) >> std::degrees >> yalpa::make_angle(dec) >> obj.vmag >> obj.bvind >> obj.sclass;
			obj.coordinates = yalpa::equatorial<double>(ra,dec);
		}
		return stm;
	}
}

ios_indic_saver::ios_indic_saver( boost::io::ios_iword_saver::state_type& state ): boost::io::ios_iword_saver(state, std::iword_index) {
	
}

==> atmos-2.98.1.tar.gz: atmos-2.98.1/src/io.cpp <==
/*
    $Id$
    Copyright (C) 2009  Sternberg Astronomical Institute, MSU

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include <iosfwd>
#include <iomanip>

#include <boost/io/ios_state.hpp>
#include <yalpa/io.h>

#include "io.h"

namespace std {

	static const int iword_index = std::ios_base::xalloc();

	std::ostream& indic( std::ostream& stm ){
		stm.iword(iword_index) = true;
		return stm;
	}
	std::ostream& operator<<( std::ostream& stm, const datum& m ){
		boost::io::ios_flags_saver fsaver( stm );
		if( std::ostream::sentry( stm ) ){
			int w = ( stm.flags() & std::ios::scientific )? 8 : 5;
			w = ( stm.iword(iword_index) )? w + 2 : w;
			int p = ( stm.iword(iword_index) ) ? 4 : std::max( 0, 4 - std::max( 1, (int)std::ceil(std::log10( m.mean ) ) ) );
			stm << std::setprecision(p) << std::setw(w) << m.mean << " "
				<< std::fixed << std::setprecision(3) << std::setw(7) << ( std::isfinite(m.errs) ? m.errs : 0 );
		}
		return stm;
	}
	std::ostream& operator<<( std::ostream& stm, const object& obj ){
		if( std::ostream::sentry( stm ) ){
			stm << obj.hd << stm.fill() << obj.name << stm.fill() << std::hours << std::sexagesimal << yalpa::make_angle( obj.coordinates.ra() ) << std::degrees << stm.fill() << yalpa::make_angle( obj.coordinates.dec() ) << stm.fill() << obj.vmag << stm.fill() << obj.bvind << stm.fill() << obj.sclass;
		}
		return stm;
	}
	std::istream& operator>>( std::istream& stm, object& obj ){
		if( std::istream::sentry( stm ) ){
			//O 2009-07-19 18:04:29 5191 Eta_UMa 13 47 32 +49 18 48  1.86 -0.19 B55
			double ra = 0,dec = 0;
			stm >> obj.hd >> obj.name >> std::sexagesimal >> std::hours >> yalpa::make_angle(ra) >> std::degrees >> yalpa::make_angle(dec) >> obj.vmag >> obj.bvind >> obj.sclass;
			obj.coordinates = yalpa::equatorial<double>(ra,dec);
		}
		return stm;
	}
}

ios_indic_saver::ios_indic_saver( boost::io::ios_iword_saver::state_type& state ): boost::io::ios_iword_saver(state, std::iword_index) {
	
}
